@@ -16,7 +16,7 @@ SEXP mer_ST_initialize(SEXP ST, SEXP Gp, SEXP Zt);
 SEXP mer_ST_setPars(SEXP x, SEXP pars);
 SEXP mer_create_L(SEXP CmP);
 SEXP mer_optimize(SEXP x);
-SEXP mer_postVar(SEXP x);
+SEXP mer_postVar(SEXP x, SEXP which);
 SEXP mer_update_L(SEXP x);
 SEXP mer_update_RX(SEXP x);
 SEXP mer_update_dev(SEXP x);
